<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Угадать</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Найдено</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормально</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Большое</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Пропустить</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Победа</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Игра окончена</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Максимальная оценка была рассчитана из следующих тридцати слов:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Классический</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Пополнение</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Выносливость</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Выбывание</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Распределение</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Тренировочный</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Отсчитывает 30 секунд и увеличивается, если отгадано правильно</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Отсчет от 3 минут.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Отсчитывает 30 секунд и добавляет к правильно отгаданным</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Отсчитывает 45 секунд и делает паузу на правильные отгадки.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Игра заканчивается после 3 неверных отгадках.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Игра заканчивается после 30 отгадок.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Отсчитывает 30 секунд и увеличивается или уменьшается по отгадкам.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Невозможно прочитать кости из файла.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Невозможно прочитать список слов из файла.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Язык поля</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Выбрать...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Примечание:&lt;/b&gt; Эти настройки вступят в силу при запуске новой игры.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Кость:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Список слов:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Словарь:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Выбрать кости</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Выбрать файл со Списком слов</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Заметка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите приложение, чтобы изменение языка вступило в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Новая Игра</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Количество слов:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Минимальная длина слова:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Легкий</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средний</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Сложный</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Случайный</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Лучшие результаты</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Результат</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пауза&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Нажмите, чтобы возобновить игру.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пожалуйста, подождите&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Загрузка игры...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Нажмите, чтобы начать новую игру.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пожалуйста, подождите&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Создание нового поля...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пожалуйста, подождите&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Оптимизация списка слов...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Новая &amp;Игра...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Заново</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Поделиться...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Конец</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Детали</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Лучшие результаты</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Показать &amp;Максимальный счет</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Никогда</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Конец игры</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Всегда</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Показать пропущенные &amp;Слова</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Показать слово &amp;Счет</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Язык Доски...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Приложение &amp;Язык..</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Управление</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Информация</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Однопользовательский вариант &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Боггл&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Релиз представлен на &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; лицензии</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Список слов на Английском основан на &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; от Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Список слов на Иврите основан на &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; от Nadav Har&apos;El и Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Выбрать Игру</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Игры Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Невозможно запустить запрошенную игру.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Сохранить Игру</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Завершить текущую игру?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Размер поля:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормальный</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Большой</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Количество слов:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Длина слов:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 или больше символов</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Тип игры:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Игра мышкой:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Выберите слово:&lt;/b&gt; Нажмите на буквы слова.&lt;br&gt;&lt;b&gt;Угадать:&lt;/b&gt; Нажмите на последнюю выбранную букву.&lt;br&gt;&lt;b&gt;Стереть буквы:&lt;/b&gt; Нажмите на ранее выбранную букву.&lt;br&gt;&lt;b&gt;Очистить слово:&lt;/b&gt; Нажмите дважды на первую выбранную букву.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Игра на клавиатуре:&lt;/b&gt;&lt;br&gt;&lt;b&gt;Выберите слово:&lt;/b&gt; Введите буквы слова.&lt;br&gt;&lt;b&gt;Угадать:&lt;/b&gt; Нажмите Enter.&lt;br&gt;&lt;b&gt;Очистить слово:&lt;/b&gt; Нажмите Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Буквы:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Игра в поиск слов</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Файл игры.</translation>
    </message>
</context>
</TS>
